@@ -1,3 +1,4 @@
+from dataclasses import dataclass
 from typing import Any, Final, Iterator, MutableMapping
 
 from .api_types import (
@@ -16,17 +17,23 @@ from .api_types import (
 __all__ = (
     "BotUpdate",
     "Context",
+    "StateContext",
 )
 
+from .helpers import Json
 
-class Context(MutableMapping[str, Any]):
-    def __init__(self, data: dict[str, Any]) -> None:
-        self._data: Final[dict[str, Any]] = data
 
-    def __getitem__(self, key: str) -> Any:
+class Context(MutableMapping[str, Json]):
+    def __init__(
+        self,
+        data: dict[str, Any],
+    ) -> None:
+        self._data: Final[dict[str, Json]] = data
+
+    def __getitem__(self, key: str) -> Json:
         return self._data[key]
 
-    def __setitem__(self, key: str, value: Any) -> None:
+    def __setitem__(self, key: str, value: Json) -> None:
         self._data[key] = value
 
     def __delitem__(self, key: str) -> None:
@@ -41,13 +48,22 @@ class Context(MutableMapping[str, Any]):
     def clear(self) -> None:
         self._data.clear()
 
-    def to_dict(self) -> dict[str, Any]:
+    def to_dict(self) -> dict[str, Json]:
         return self._data
 
 
+@dataclass
+class StateContext:
+    state: str | None
+    context: Context
+
+
 class BotUpdate(MutableMapping[str, Any]):
     def __init__(
-        self, state: str | None, context: Context, update: Update
+        self,
+        state: str | None,
+        context: Context,
+        update: Update,
     ) -> None:
         self._state: str | None = state
         self._context: Final[Context] = context
