@@ -2,21 +2,21 @@ import re
 from dataclasses import dataclass
 from typing import Final
 
-from . import Bot, FilterProtocol
+from .bot import Bot, FilterProtocol
 from .bot_update import BotUpdate
 from .constants import ChatType, ContentType, UpdateType
 
 __all__ = (
-    "UpdateTypeFilter",
-    "StateFilter",
+    "ANDFilter",
+    "CallbackQueryDataFilter",
     "CommandsFilter",
     "ContentTypeFilter",
-    "MessageTextFilter",
-    "CallbackQueryDataFilter",
-    "PrivateChatFilter",
     "GroupChatFilter",
+    "MessageTextFilter",
     "ORFilter",
-    "ANDFilter",
+    "PrivateChatFilter",
+    "StateFilter",
+    "UpdateTypeFilter",
 )
 
 
@@ -25,7 +25,7 @@ class UpdateTypeFilter:
     update_type: UpdateType
 
     async def check(self, _: Bot, update: BotUpdate) -> bool:
-        return getattr(update, self.update_type.value) is not None
+        return getattr(update, self.update_type) is not None
 
 
 @dataclass(frozen=True)
@@ -67,7 +67,7 @@ class ContentTypeFilter:
         else:
             return False
         for content_type in self.content_types:
-            if getattr(message, content_type.value) is not None:
+            if getattr(message, content_type) is not None:
                 return True
         return False
 
